GENAI Package
==============

.. automodule:: genai
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   genai.exceptions
   genai.schemas
   genai.services

Submodules
----------

.. toctree::
   :maxdepth: 4

   genai.credentials
   genai.metadata
   genai.model
